@@ -10,6 +10,7 @@ from mindsdb_sql.parser.dialects.mindsdb.create_predictor import CreatePredictor
 from mindsdb_sql.parser.dialects.mindsdb.create_datasource import CreateDatasource
 from mindsdb_sql.parser.dialects.mindsdb.create_view import CreateView
 from mindsdb_sql.parser.dialects.mindsdb.latest import Latest
+from mindsdb_sql.parser.dialects.mindsdb.create_file import CreateFile
 from mindsdb_sql.exceptions import ParsingException
 from mindsdb_sql.parser.dialects.mindsdb.lexer import MindsDBLexer
 from mindsdb_sql.parser.dialects.mindsdb.retrain_predictor import RetrainPredictor
@@ -58,6 +59,8 @@ class MindsDBParser(Parser):
        'delete',
        'drop_database',
        'drop_view',
+       'drop_table',
+       'create_table',
        )
     def query(self, p):
         return p[0]
@@ -114,10 +117,29 @@ class MindsDBParser(Parser):
     # Set
 
     @_('SET id identifier')
+    @_('SET id identifier COLLATE constant')
+    @_('SET id identifier COLLATE DEFAULT')
+    @_('SET id constant')
+    @_('SET id constant COLLATE constant')
+    @_('SET id constant COLLATE DEFAULT')
     def set(self, p):
         if not p.id.lower() == 'names':
             raise ParsingException(f'Expected "SET names", got "SET {p.id}"')
-        return Set(category=p.id.lower(), arg=p.identifier)
+        if isinstance(p[2], Constant):
+            arg = Identifier(p[2].value)
+        else:
+            # is identifier
+            arg = p[2]
+
+        params = {}
+        if hasattr(p, 'COLLATE'):
+            if isinstance(p[4], Constant):
+                val = p[4]
+            else:
+                val = SpecialConstant('DEFAULT')
+            params['COLLATE'] = val
+
+        return Set(category=p.id.lower(), arg=arg, params=params)
 
     # set charset
     @_('SET charset constant')
@@ -417,9 +439,10 @@ class MindsDBParser(Parser):
 
     # DROP PREDICTOR
     @_('DROP PREDICTOR identifier',
-       'DROP TABLE identifier')
+       'DROP PREDICTOR IF_EXISTS identifier')
     def drop_predictor(self, p):
-        return DropPredictor(p.identifier)
+        if_exists = hasattr(p, 'IF_EXISTS')
+        return DropPredictor(p.identifier, if_exists=if_exists)
 
     # DROP DATASOURCE
     @_('DROP DATASOURCE identifier')
@@ -431,6 +454,34 @@ class MindsDBParser(Parser):
     def drop_dataset(self, p):
         return DropDataset(p.identifier)
 
+    # DROP TABLE
+    @_('DROP TABLE IF_EXISTS identifier')
+    @_('DROP TABLE identifier')
+    def drop_table(self, p):
+        if_exists = hasattr(p, 'IF_EXISTS')
+        return DropTables(tables=[p.identifier], if_exists=if_exists)
+
+    # create table
+    @_('CREATE TABLE identifier select')
+    @_('CREATE TABLE identifier LPAREN select RPAREN')
+    @_('CREATE OR REPLACE TABLE identifier select')
+    @_('CREATE OR REPLACE TABLE identifier LPAREN select RPAREN')
+    def create_table(self, p):
+        # TODO create table with columns
+        is_replace = False
+        if hasattr(p, 'REPLACE'):
+            is_replace = True
+        return CreateTable(
+            name=p.identifier,
+            is_replace=is_replace,
+            from_select=p.select
+        )
+
+    @_('CREATE TABLE identifier USING kw_parameter_list')
+    def create_table(self, p):
+        params = p.kw_parameter_list
+        return CreateFile(name=p.identifier, **params)
+
     @_('create_predictor USING kw_parameter_list')
     def create_predictor(self, p):
         p.create_predictor.using = p.kw_parameter_list
@@ -460,12 +511,16 @@ class MindsDBParser(Parser):
         p.create_predictor.order_by = p.ordering_terms
         return p.create_predictor
 
-    @_('CREATE PREDICTOR identifier FROM identifier WITH LPAREN raw_query RPAREN optional_data_source_name PREDICT result_columns')
     @_('CREATE PREDICTOR identifier FROM identifier LPAREN raw_query RPAREN optional_data_source_name PREDICT result_columns')
-    @_('CREATE TABLE identifier FROM identifier WITH LPAREN raw_query RPAREN optional_data_source_name PREDICT result_columns')
     @_('CREATE TABLE identifier FROM identifier LPAREN raw_query RPAREN optional_data_source_name PREDICT result_columns')
     @_('CREATE PREDICTOR identifier PREDICT result_columns')
+    @_('CREATE OR REPLACE PREDICTOR identifier FROM identifier LPAREN raw_query RPAREN optional_data_source_name PREDICT result_columns')
+    @_('CREATE OR REPLACE TABLE identifier FROM identifier LPAREN raw_query RPAREN optional_data_source_name PREDICT result_columns')
+    @_('CREATE OR REPLACE PREDICTOR identifier PREDICT result_columns')
     def create_predictor(self, p):
+        is_replace = False
+        if hasattr(p, 'REPLACE'):
+            is_replace = True
 
         query_str = None
         if hasattr(p, 'raw_query'):
@@ -483,6 +538,7 @@ class MindsDBParser(Parser):
             query_str=query_str,
             datasource_name=getattr(p, 'optional_data_source_name', None),
             targets=p.result_columns,
+            is_replace=is_replace
         )
 
     @_('AS identifier')
@@ -498,10 +554,19 @@ class MindsDBParser(Parser):
        'CREATE datasource_engine COMMA PARAMETERS json',
        'CREATE datasource_engine PARAMETERS EQUALS json',
        'CREATE datasource_engine PARAMETERS json')
+    @_('CREATE OR REPLACE datasource_engine COMMA PARAMETERS EQUALS json',
+       'CREATE OR REPLACE datasource_engine COMMA PARAMETERS json',
+       'CREATE OR REPLACE datasource_engine PARAMETERS EQUALS json',
+       'CREATE OR REPLACE datasource_engine PARAMETERS json')
     def create_integration(self, p):
+        is_replace = False
+        if hasattr(p, 'REPLACE'):
+            is_replace = True
+
         return CreateDatasource(name=p.datasource_engine['id'],
-                                 engine=p.datasource_engine['engine'],
-                                 parameters=p.json)
+                                engine=p.datasource_engine['engine'],
+                                is_replace=is_replace,
+                                parameters=p.json)
 
     @_('DATASOURCE id WITH ENGINE EQUALS string',
        'DATASOURCE id WITH ENGINE string',
@@ -702,11 +767,15 @@ class MindsDBParser(Parser):
 
     @_('from_table AS identifier',
        'from_table identifier',
+       'from_table AS dquote_string',
+       'from_table dquote_string',
        'from_table')
     def from_table_aliased(self, p):
         entity = p.from_table
         if hasattr(p, 'identifier'):
             entity.alias = p.identifier
+        if hasattr(p, 'dquote_string'):
+            entity.alias = Identifier(p.dquote_string)
         return entity
 
     @_('LPAREN query RPAREN')
@@ -760,12 +829,18 @@ class MindsDBParser(Parser):
         return [p.result_column]
 
     @_('result_column AS identifier',
-       'result_column identifier')
+       'result_column identifier',
+       'result_column AS dquote_string',
+       'result_column dquote_string')
     def result_column(self, p):
         col = p.result_column
         if col.alias:
             raise ParsingException(f'Attempt to provide two aliases for {str(col)}')
-        col.alias = p.identifier
+        if hasattr(p, 'dquote_string'):
+            alias = Identifier(p.dquote_string)
+        else:
+            alias = p.identifier
+        col.alias = alias
         return col
 
     @_('LPAREN select RPAREN')
@@ -781,10 +856,27 @@ class MindsDBParser(Parser):
 
     @_('expr',
        'function',
-       'window_function')
+       'window_function',
+       'case')
     def result_column(self, p):
         return p[0]
 
+    # case
+    @_('CASE case_conditions ELSE expr END')
+    def case(self, p):
+        return Case(rules=p.case_conditions, default=p.expr)
+
+    @_('case_condition',
+       'case_conditions case_condition')
+    def case_conditions(self, p):
+        arr = getattr(p, 'case_conditions', [])
+        arr.append(p.case_condition)
+        return arr
+
+    @_('WHEN expr THEN expr')
+    def case_condition(self, p):
+        return [p.expr0, p.expr1]
+
     # Window function
     @_('function OVER LPAREN window RPAREN')
     def window_function(self, p):
@@ -927,20 +1019,12 @@ class MindsDBParser(Parser):
         return [p.expr0, p.expr1]
 
     @_('identifier')
-    def expr(self, p):
-        return p.identifier
-
     @_('parameter')
-    def expr(self, p):
-        return p.parameter
-
     @_('constant')
-    def expr(self, p):
-        return p.constant
-
     @_('latest')
+    @_('function')
     def expr(self, p):
-        return p.latest
+        return p[0]
 
     @_('LATEST')
     def latest(self, p):
@@ -1046,12 +1130,16 @@ class MindsDBParser(Parser):
 
 
     @_('identifier DOT identifier')
+    @_('identifier DOT star')
     def identifier(self, p):
-        p.identifier0.parts += p.identifier1.parts
-        return p.identifier0
+        node = p[0]
+        if isinstance(p[2], Star):
+            node.parts.append(p[2])
+        else:
+            node.parts += p[2].parts
+        return node
 
-    @_('id',
-       'dquote_string')
+    @_('id')
     def identifier(self, p):
         value = p[0]
         return Identifier.from_path_str(value)
@@ -1115,6 +1203,7 @@ class MindsDBParser(Parser):
        'PUBLICATION',
        'PUBLICATIONS',
        'REPEATABLE',
+       'REPLACE',
        'REPLICA',
        'REPLICAS',
        'RETRAIN',
