@@ -1,14 +1,15 @@
 import copy
 from collections import defaultdict
 from mindsdb_sql.exceptions import PlanningException
+from mindsdb_sql.parser import ast
 from mindsdb_sql.parser.ast import (Select, Identifier, Join, Star, BinaryOperation, Constant, OrderBy,
-                                    BetweenOperation, Union, NullConstant)
+                                    BetweenOperation, Union, NullConstant, CreateTable)
 
 from mindsdb_sql.parser.dialects.mindsdb.latest import Latest
 from mindsdb_sql.planner.steps import (FetchDataframeStep, ProjectStep, JoinStep, ApplyPredictorStep,
                                        ApplyPredictorRowStep, FilterStep, GroupByStep, LimitOffsetStep, OrderByStep,
                                        UnionStep, MapReduceStep, MultipleSteps, ApplyTimeseriesPredictorStep,
-                                       GetPredictorColumns)
+                                       GetPredictorColumns, SaveToTable)
 from mindsdb_sql.planner.ts_utils import (validate_ts_where_condition, find_time_filter, replace_time_filter,
                                           find_and_remove_time_filter)
 from mindsdb_sql.planner.utils import (get_integration_path_from_identifier,
@@ -17,9 +18,10 @@ from mindsdb_sql.planner.utils import (get_integration_path_from_identifier,
                                        disambiguate_predictor_column_identifier, recursively_disambiguate_identifiers,
                                        get_deepest_select,
                                        recursively_extract_column_values,
-                                       recursively_check_join_identifiers_for_ambiguity
-                                       )
+                                       recursively_check_join_identifiers_for_ambiguity,
+                                       query_traversal)
 from mindsdb_sql.planner.query_plan import QueryPlan
+from mindsdb_sql.planner import utils
 from .query_prepare import PreparedStatementPlanner
 
 
@@ -40,10 +42,15 @@ class QueryPlanner():
         self.predictor_metadata = predictor_metadata or defaultdict(dict)
         self.default_namespace = default_namespace
 
+        # allow to select from mindsdb namespace
+        # self.integrations.append(self.predictor_namespace)
+
         self.statement = None
 
     def is_predictor(self, identifier):
         parts = identifier.parts
+        if not parts[-1].lower() in self.predictor_metadata:
+            return False
         if parts[0].lower() == self.predictor_namespace:
             return True
         elif len(parts) == 1 and self.default_namespace == self.predictor_namespace:
@@ -218,7 +225,7 @@ class QueryPlanner():
         if isinstance(time_filter, BetweenOperation):
             between_from = time_filter.args[1]
             preparation_time_filter = BinaryOperation('<', args=[Identifier(predictor_time_column_name), between_from])
-            replace_time_filter(preparation_where2, time_filter, preparation_time_filter)
+            preparation_where2 = replace_time_filter(preparation_where2, time_filter, preparation_time_filter)
             integration_select_1 = Select(targets=[Star()],
                                         from_table=table,
                                         where=add_order_not_null(preparation_where2),
@@ -246,7 +253,7 @@ class QueryPlanner():
             preparation_time_filter_op = {'>': '<=', '>=': '<'}[time_filter.op]
 
             preparation_time_filter = BinaryOperation(preparation_time_filter_op, args=[Identifier(predictor_time_column_name), time_filter_date])
-            replace_time_filter(preparation_where2, time_filter, preparation_time_filter)
+            preparation_where2 = replace_time_filter(preparation_where2, time_filter, preparation_time_filter)
             integration_select_1 = Select(targets=[Star()],
                                           from_table=table,
                                           where=add_order_not_null(preparation_where2),
@@ -352,6 +359,12 @@ class QueryPlanner():
         new_join.condition.args = new_condition_args
         new_join.left = Identifier(left_table_path, alias=left_table.alias)
         new_join.right = Identifier(right_table_path, alias=right_table.alias)
+
+        # FIXME: INFORMATION_SCHEMA with condition
+        # clear join condition for INFORMATION_SCHEMA
+        if right_integration_name == 'INFORMATION_SCHEMA':
+            new_join.condition = None
+
         return self.plan.add_step(JoinStep(left=select_left_step.result, right=select_right_step.result, query=new_join))
 
     def plan_project(self, query, dataframe):
@@ -364,32 +377,73 @@ class QueryPlanner():
                 out_identifiers.append(new_identifier)
         return self.plan.add_step(ProjectStep(dataframe=dataframe, columns=out_identifiers))
 
-    def plan_join(self, query):
+    def get_aliased_fields(self, targets):
+        # get aliases from select target
+        aliased_fields = {}
+        for target in targets:
+            if target.alias is not None:
+                aliased_fields[target.alias.to_string()] = target
+        return aliased_fields
+
+    def plan_join(self, query, integration=None):
         join = query.from_table
+        join_left = join.left
+        join_right = join.right
+
+        if isinstance(join_left, Select):
+            # dbt query.
+            # TODO support complex query. Only one table is supported at the moment.
+            if not isinstance(join_left.from_table, Identifier):
+                raise PlanningException(f'Statement not supported: {query.to_string()}')
+
+            # move properties to upper query
+            query = join_left
+
+            if query.from_table.alias is not None:
+                table_alias = query.from_table.alias.parts[0]
+            else:
+                table_alias = query.from_table.parts[-1]
+
+            def add_aliases(node, is_table, **kwargs):
+                if not is_table and isinstance(node, Identifier):
+                    if len(node.parts) == 1:
+                        # add table alias to field
+                        node.parts.insert(0, table_alias)
+
+            query_traversal(query.where, add_aliases)
+
+            if isinstance(query.from_table, Identifier):
+                if integration is not None and query.from_table.parts[0] != integration:
+                    # add integration name to table
+                    query.from_table.parts.insert(0, integration)
+
+            join_left = join_left.from_table
+
+        aliased_fields = self.get_aliased_fields(query.targets)
 
         recursively_check_join_identifiers_for_ambiguity(query.where)
-        recursively_check_join_identifiers_for_ambiguity(query.group_by)
+        recursively_check_join_identifiers_for_ambiguity(query.group_by, aliased_fields=aliased_fields)
         recursively_check_join_identifiers_for_ambiguity(query.having)
-        recursively_check_join_identifiers_for_ambiguity(query.order_by)
+        recursively_check_join_identifiers_for_ambiguity(query.order_by, aliased_fields=aliased_fields)
 
-        if isinstance(join.left, Identifier) and isinstance(join.right, Identifier):
-            if self.is_predictor(join.left) and self.is_predictor(join.right):
-                raise PlanningException(f'Can\'t join two predictors {str(join.left.parts[0])} and {str(join.left.parts[1])}')
+        if isinstance(join_left, Identifier) and isinstance(join_right, Identifier):
+            if self.is_predictor(join_left) and self.is_predictor(join_right):
+                raise PlanningException(f'Can\'t join two predictors {str(join_left.parts[0])} and {str(join_left.parts[1])}')
 
             predictor_namespace = None
             predictor = None
             table = None
             predictor_is_left = False
-            if self.is_predictor(join.left):
-                predictor_namespace, predictor = get_predictor_namespace_and_name_from_identifier(join.left, self.default_namespace)
+            if self.is_predictor(join_left):
+                predictor_namespace, predictor = get_predictor_namespace_and_name_from_identifier(join_left, self.default_namespace)
                 predictor_is_left = True
             else:
-                table = join.left
+                table = join_left
 
-            if self.is_predictor(join.right):
-                predictor_namespace, predictor = get_predictor_namespace_and_name_from_identifier(join.right, self.default_namespace)
+            if self.is_predictor(join_right):
+                predictor_namespace, predictor = get_predictor_namespace_and_name_from_identifier(join_right, self.default_namespace)
             else:
-                table = join.right
+                table = join_right
 
             last_step = None
             if predictor:
@@ -435,7 +489,12 @@ class QueryPlanner():
                 join_step = self.plan_join_two_tables(join)
                 last_step = join_step
                 if query.where:
-                    last_step = self.plan.add_step(FilterStep(dataframe=last_step.result, query=query.where))
+                    # FIXME: INFORMATION_SCHEMA with Where
+                    right_integration_name, _ = self.get_integration_path_from_identifier_or_error(join.right)
+                    if right_integration_name == 'INFORMATION_SCHEMA':
+                        ...
+                    else:
+                        last_step = self.plan.add_step(FilterStep(dataframe=last_step.result, query=query.where))
 
                 if query.group_by:
                     group_by_targets = []
@@ -460,7 +519,22 @@ class QueryPlanner():
             raise PlanningException(f'Join of unsupported objects, currently only tables and predictors can be joined.')
         return self.plan_project(query, last_step.result)
 
-    def plan_select(self, query):
+    def plan_create_table(self, query):
+        if query.from_select is None:
+            raise PlanningException(f'Not implemented "create table": {query.to_string()}')
+
+        integration_name = query.name.parts[0]
+
+        last_step = self.plan_select(query.from_select, integration=integration_name)
+
+        # create table step
+        self.plan.add_step(SaveToTable(
+            table=query.name,
+            dataframe=last_step,
+            is_replace=query.is_replace,
+        ))
+
+    def plan_select(self, query, integration=None):
         from_table = query.from_table
 
         if isinstance(from_table, Identifier):
@@ -471,7 +545,7 @@ class QueryPlanner():
         elif isinstance(from_table, Select):
             return self.plan_integration_nested_select(query)
         elif isinstance(from_table, Join):
-            return self.plan_join(query)
+            return self.plan_join(query, integration=integration)
         else:
             raise PlanningException(f'Unsupported from_table {type(from_table)}')
 
@@ -490,11 +564,14 @@ class QueryPlanner():
             self.plan_select(query)
         elif isinstance(query, Union):
             self.plan_union(query)
+        elif isinstance(query, CreateTable):
+            self.plan_create_table(query)
         else:
             raise PlanningException(f'Unsupported query type {type(query)}')
 
         return self.plan
 
+
     def prepare_steps(self, query):
         statement_planner = PreparedStatementPlanner(self)
 
