@@ -5,18 +5,22 @@ from mindsdb_sql.planner import steps
 from mindsdb_sql.planner import utils
 
 
+def to_string(identifier):
+    # alternative to AST.to_string() but without quoting
+    return '.'.join(identifier.parts)
+
 class Table:
     def __init__(self,  node=None, ds=None, is_predictor=None):
         self.node = node
         self.is_predictor = is_predictor
         self.ds = ds
-        self.name = node.to_string(alias=False)
+        self.name = to_string(node)
         self.columns = None
         # None is unknown
         self.columns_map = None
         self.keys = None
         if node.alias:
-            self.alias = node.alias.to_string()
+            self.alias = to_string(node.alias)
         else:
             self.alias = None
             # self.alias = self.name
@@ -47,7 +51,7 @@ class Column:
 
 class Statement:
     def __init__(self):
-        self.columns = None
+        self.columns = []
         # self.query = None
         self.params = None
         self.result = None
@@ -102,7 +106,7 @@ class PreparedStatementPlanner():
 
         parameters = []
         for param in stmt.params:
-            name = param.to_string(alias=False)
+            name = '?'
             parameters.append(dict(
                 alias=name,
                 type='str',
@@ -145,7 +149,7 @@ class PreparedStatementPlanner():
 
         if table.alias is not None:
             # access by alias if table is having alias
-            keys = [table.alias.to_string()]
+            keys = [to_string(table.alias)]
 
         else:
             # access by table name, in all variants
@@ -237,7 +241,7 @@ class PreparedStatementPlanner():
             # column alias
             alias = None
             if t.alias is not None:
-                alias = t.alias.to_string()
+                alias = to_string(t.alias)
 
             if isinstance(t, ast.Star):
                 if len(stmt.tables_lvl1) == 0:
@@ -445,6 +449,7 @@ class PreparedStatementPlanner():
             Column(name='Variable_name', type='str'),
             Column(name='Value', type='str'),
         ]
+        return []
 
     def prepare_steps(self, query):
 
@@ -455,16 +460,7 @@ class PreparedStatementPlanner():
 
         query = copy.deepcopy(query)
 
-        # find all parameters
-        params = []
-
-        def params_find(node, **kwargs):
-            if isinstance(node, ast.Parameter):
-                params.append(node)
-                return node
-                # return ast.Constant('0')
-
-        utils.query_traversal(query, params_find)
+        params = utils.get_query_params(query)
 
         stmt.params = params
 
@@ -476,15 +472,20 @@ class PreparedStatementPlanner():
             # get column definition only from select
             return self.prepare_select(query.left)
         if isinstance(query, ast.Insert):
-            return self.prepare_insert(query)
+            # return self.prepare_insert(query)
+            # TODO do we need columns?
+            return []
         if isinstance(query, ast.Delete):
             ...
             # TODO do we need columns?
+            return []
         if isinstance(query, ast.Show):
             return self.prepare_show(query)
         else:
-            raise NotImplementedError(query.__name__)
 
+            # do nothing
+            return []
+            # raise NotImplementedError(query.__name__)
 
     def execute_steps(self, params=None):
         # find all parameters
@@ -501,24 +502,22 @@ class PreparedStatementPlanner():
         query = self.planner.query
 
         if params is not None:
-            params = copy.deepcopy(params)
 
             if len(params) != len(stmt.params):
                 raise PlanningException("Count of execution parameters don't match prepared statement")
 
-            def params_replace(node, **kwargs):
-                if isinstance(node, ast.Parameter):
-                    value = params.pop(0)
-                    return ast.Constant(value)
+            query = utils.fill_query_params(query, params)
 
-            # put parameters into query
-            utils.query_traversal(query, params_replace)
             self.planner.query = query
 
         # prevent from second execution
         stmt.params = None
 
-        if isinstance(query, ast.Select) or isinstance(query, ast.Union):
+        if (
+                isinstance(query, ast.Select)
+                or isinstance(query, ast.Union)
+                or isinstance(query, ast.CreateTable)
+        ):
             return self.plan_query(query)
         else:
             return []
