@@ -187,19 +187,22 @@ def recursively_extract_column_values(op, row_dict, predictor):
         raise PlanningException(f'Only \'and\' and \'=\' operations allowed in WHERE clause, found: {op.to_tree()}')
 
 
-def recursively_check_join_identifiers_for_ambiguity(item):
+def recursively_check_join_identifiers_for_ambiguity(item, aliased_fields=None):
     if item is None:
         return
     elif isinstance(item, Identifier):
         if len(item.parts) == 1:
+            if aliased_fields is not None and item.parts[0] in aliased_fields:
+                # is alias
+                return
             raise PlanningException(f'Ambigous identifier {str(item)}, provide table name for operations on a join.')
     elif isinstance(item, Operation):
-        recursively_check_join_identifiers_for_ambiguity(item.args)
+        recursively_check_join_identifiers_for_ambiguity(item.args, aliased_fields=aliased_fields)
     elif isinstance(item, OrderBy):
-        recursively_check_join_identifiers_for_ambiguity(item.field)
+        recursively_check_join_identifiers_for_ambiguity(item.field, aliased_fields=aliased_fields)
     elif isinstance(item, list):
         for arg in item:
-            recursively_check_join_identifiers_for_ambiguity(arg)
+            recursively_check_join_identifiers_for_ambiguity(arg, aliased_fields=aliased_fields)
 
 
 def get_deepest_select(select):
@@ -364,4 +367,31 @@ def convert_join_to_list(join):
         condition=join.condition
     ))
 
-    return items
\ No newline at end of file
+    return items
+
+
+def get_query_params(query):
+    # find all parameters
+    params = []
+
+    def params_find(node, **kwargs):
+        if isinstance(node, ast.Parameter):
+            params.append(node)
+            return node
+
+    query_traversal(query, params_find)
+    return params
+
+def fill_query_params(query, params):
+
+    params = copy.deepcopy(params)
+
+    def params_replace(node, **kwargs):
+        if isinstance(node, ast.Parameter):
+            value = params.pop(0)
+            return ast.Constant(value)
+
+    # put parameters into query
+    query_traversal(query, params_replace)
+
+    return query
